% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/MiShrinkAjust.R
\name{MiShrinkAjust}
\alias{MiShrinkAjust}
\title{Ajust learning rate parameter for fitting  generalized boosted regression modelsfor fitting  generalized boosted regression models}
\usage{
MiShrinkAjust(Matrix, specimens, test.frac = 5, times = 5,
  ntrees = 1000, shrinkage = c(0.001, 0.01, 0.1), intdepth = 2)
}
\arguments{
\item{Matrix}{numeric matrix of expression data where each row corresponds to a probe (gene, transcript),
and each column correspondes to a specimen (patient).}

\item{specimens}{factor vector with two levels specifying specimens in the columns of the \code{Matrix}}

\item{test.frac}{integer specifying fraction of data to use for model testing}

\item{times}{integer specifying number of trials}

\item{ntrees}{integer specifying the total number of decision trees (boosting iterations).}

\item{shrinkage}{numeric vector specifying the learning rate.
Scales the step size in the gradient descent procedure. The tested parameter.}

\item{intdepth}{vinteger specifying the maximum depth of each tree.}
}
\value{
list of 2
\cr
\code{train.accuracy} - a data frame of train data classification accuracy
for each \code{shrinkage} value in each trial and their median.
\cr
\code{test.accuracy} - a data frame of test data classification accuracy
for each \code{shrinkage} value in each trial and their median.
\cr
Also a plot for \code{shrinkage} versus Accuracy is produced.
}
\description{
Test learning rate (shrinkage) parameter for microarrat data binary classification using gradient boosting
over desicion trees.
}
\details{
\code{test.frac} defines fraction of specimens that will be used for model testing. For example, if
\code{test.frac}=5 then 4/5th of specimens will be used for model fitting (train data) and 1/5th of specimens
will be used for model testing (test data). Specimens for test and train data will be selected by random.
So with \code{times}>1 train and test data will differ each time.
\cr
While boosting basis functions are iteratively adding in a greedy fashion
so that each additional basis function further reduces the selected loss function.
Gaussian distribution (squared error) is used.
\code{ntrees}, \code{shrinkage}, \code{intdeep} are parameters for model tuning.
See \code{\link{gbm}} for details.
\cr
Use \code{\link{MiIntDepthAjust}} and \code{\link{MiNTreesAjust}} for ajusting other parameters.
\cr
Function is rather time-costing. If specimens are not equally distributed between two classified groups,
NA may be produced.
}
\examples{
data("IMexpression");data("IMspecimen")
#sample expression matrix and specimen data for binary classification,
#only "NORM" and "EBV" specimens are left
SampleMatrix<-MiDataSample(IMexpression, IMspecimen$diagnosis,"norm", "ebv")
SampleSpecimen<-MiSpecimenSample(IMspecimen$diagnosis, "norm", "ebv")
#Fitting, low tuning for faster running. Test shrinkage
set.seed(1)
ClassRes<-MiShrinkAjust(SampleMatrix, SampleSpecimen, test.frac = 5, times = 3,
                        ntrees = 10, shrinkage = c(0.1, 1), intdepth = 2)
ClassRes[[1]] # train accuracy
ClassRes[[2]] # test accuracy

}
\seealso{
\code{\link{gbm}}, \code{\link{MiIntDepthAjust}}, \code{\link{MiNTreesAjust}}
}
\author{
Elena N. Filatova
}
